@@ -221,7 +221,7 @@ def constrain_field(Constraints,u = None,v = None,w = None, BaseName = 'Turb', \
     Rdist = np.sqrt(Xdist**2 + Ydist**2 + Zdist**2)
     Rlimit = max( [L/10, min([dx, dy, dz])])
     Rexceed = (Rdist > 0) & (Rdist < Rlimit)
-    ValidDistIndex = np.full((Rdist.shape[0]),True,dtype = 'Bool')
+    ValidDistIndex = np.full((Rdist.shape[0]),True,dtype = 'bool')
     for i in range(Nconstraints):
         if np.any(Rexceed[i,:i]):
             Rexceed[i,:] = 0
